@@ -2,11 +2,12 @@
 #' 
 #' @method mean ff
 #' @export
-#' @example examples/mean.R
+#' @example ../examples/mean.R
 #' @param x a ff vector
 #' @param trim percentage of robustness, between 0 and 1
 #' @param ... other arguments passed to \code{mean}
 #' @param range a \code{ri} or an \code{integer} vector of \code{length==2} giving a range restriction for chunked processing
+#' @importFrom stats weighted.mean
 #' @return mean value
 mean.ff <- function(x, trim=0, ..., range=NULL){
     r <- checkRange(range, x)
@@ -18,7 +19,7 @@ mean.ff <- function(x, trim=0, ..., range=NULL){
 	   n <- length(x)     #calculate length
 	   r[1] <- floor(n * trim)
 	   r[2] <- n - r[1]
-	}
+	  }
 	
    
    res <- sapply( chunk(x, from=min(r), to=max(r))
@@ -30,15 +31,3 @@ mean.ff <- function(x, trim=0, ..., range=NULL){
 				    )
    weighted.mean(res['mean',], res['w',])
 }
-
-#' Mean of ffdf vector
-#' 
-#' @method mean ffdf
-#' @export
-#' @param x a \code{ffdf}
-#' @param ... other arguments passed to \code{\link{mean.ff}}
-#' @param range a \code{ri} or an \code{integer} vector of \code{length==2} giving a range restriction for chunked processing
-#' @return a vector with the mean values
-mean.ffdf <- function(x, ..., range=NULL){
-   sapply(physical(x), mean, ..., range=range)
-}
\ No newline at end of file
